@@ -1,4 +1,4 @@
-# $Id: CDDB.pm,v 1.22 2000/04/30 02:33:11 troc Exp $
+# $Id: CDDB.pm,v 1.23 2001/03/25 03:48:30 troc Exp $
 # Documentation and Copyright exist after __END__
 
 package CDDB;
@@ -15,9 +15,8 @@ use Sys::Hostname;
 # list of known cddb servers
 
 my @cddb_hosts =
-  ( [ 'cddb.cddb.com'     => 8880 ],
-    [ 'sj.ca.us.cddb.com' => 8880 ],
-    [ 'sc.ca.us.cddb.com' => 8880 ],
+  ( [ 'freedb.freedb.org'    => 8880 ],
+    [ 'uk.freedb.freedb.org' => 8880 ],
   );
 
 #------------------------------------------------------------------------------
@@ -31,7 +30,7 @@ eval {
 
 #------------------------------------------------------------------------------
 
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 #------------------------------------------------------------------------------
 # code "adapted" from Net::Cmd, because actually using Net::Cmd hurt real bad
@@ -177,7 +176,7 @@ sub new {
     login         => $login,
     libname       => 'CDDB.pm',
     libver        => $VERSION,
-    cddbmail      => 'cddb-test@submit.cddb.com',
+    cddbmail      => 'test-submit@freedb.org',
     debug         => $debug,
     host          => $host,
     port          => $port,
@@ -549,7 +548,12 @@ sub submit_disc {
     $host = $ENV{SMTPHOSTS};
   }
   else {
-    $host = 'mail';
+    if (defined inet_aton('mail')) {
+      $host = 'mail';
+    }
+    else {
+      $host = 'localhost';
+    }
   }
                                         # optional... override bad choice
   my $from =  (exists $params{From})
